#!/bin/bash
#
# This script enables or disables running BeagleRT when the board starts
# up.

BBB_ADDRESS="root@192.168.7.2"
BBB_PATH="/root/BeagleRT"
ENABLE_STARTUP=1
COMMAND_ARGS=

# This path is hard-coded in the BeagleRT image at present.
BBB_STARTUP_SCRIPT="/root/BeagleRT_startup.sh"

function usage
{
    THIS_SCRIPT=`basename "$0"`
    echo "Usage: $THIS_SCRIPT [-b path-on-beaglebone] [-c command-line-args] [-n]"

    echo "
    This script enables (by default) or disables running the BeagleRT
    project at startup. The -n option disables auto-startup, otherwise
    auto-startup is enabled. The -b option changes the default path, which
    is otherwise $BBB_PATH. The -c option passes command-line arguments to
    the BeagleRT program; enclose the argument string in quotes."
}

OPTIND=1

while getopts "b:c:nh" opt; do
    case $opt in
        b)            BBB_PATH=$OPTARG
                      ;;
        c)            COMMAND_ARGS=$OPTARG
                      ;;
        n)            ENABLE_STARTUP=0
                      ;;
        h|\?)         usage
                      exit 1
    esac
done

shift $((OPTIND-1))

if [ $ENABLE_STARTUP -eq 0 ]
then
    echo "Disabling BeagleRT at startup..."

    ssh $BBB_ADDRESS "echo \"#!/bin/sh
#
# This file is autogenerated by BeagleRT. Do not edit!

# Run on startup disabled -- nothing to do here\" > $BBB_STARTUP_SCRIPT"

else
    echo "Enabling BeagleRT at startup..."

    ssh $BBB_ADDRESS "echo \"#!/bin/sh
#
# This file is autogenerated by BeagleRT. Do not edit!

echo Running BeagleRT...
screen -S BeagleRT -d -m $BBB_PATH/BeagleRT $COMMAND_ARGS\" > $BBB_STARTUP_SCRIPT"

fi